manytoonechoicesdelegate — Camelot documentation

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »
- Camelot API »
- view »
- controls »
- delegates »

# manytoonechoicesdelegate

class `camelot.view.controls.delegates.manytoonechoicesdelegate.` `ManyToOneChoicesDelegate`(parent=None, editable=True, **kwargs)

  Display a ManyToOne field as a ComboBox, filling the list of choices with the objects of the target class.

  The items in the ComboBox are the unicode representation of the related objects. So these classes need an implementation of their __unicode__ method to show up in a human readable way in the ComboBox.

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »
- Camelot API »
- view »
- controls »
- delegates »

Comments
blog comments powered by Disqus